# Table of Contents

- [obsolescence-risk-management-advanced](<./obsolescence-risk-management-advanced.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Advanced Practices](<./Advanced-Practices.md>)
  - [Automation to Trigger an End-of-Life Process](<./Advanced-Practices/Automation-to-Trigger-an-End-of-Life-Process.md>)
  - [Using SAP LeanIX Architecture and Road Map Planning for Obsolescence Risk Management](<./Advanced-Practices/Using-SAP-LeanIX-Architecture-and-Road-Map-Planning-for-Obsolescence-Risk-Management.md>)
  - [Aggregating Obsolescence Risk for Self-Built Software](<./Advanced-Practices/Aggregating-Obsolescence-Risk-for-Self-Built-Software.md>)
  - [Aggregating Obsolescence Risk Through Technical Platforms](<./Advanced-Practices/Aggregating-Obsolescence-Risk-Through-Technical-Platforms.md>)
